# Changelog

## 0.1.0 (2025-04-25)

- Support basic operations for worldquant brain: login, alpha simulation, alpha query, dataset query

## 0.1.1(2025-04-27)

- Add more utility functions for alpha mining

# Commands

+ Local debug installation：`pip install -e .`
+ Publish to pypi: `poetry publish --build`